--[[ TitanItemRack

	Based from Chicogrande's TitanRecap.

	This is a Titan plugin for versions 1.83 or greater versions of ItemRack.

	1.1 1/28/06 - minor fix of an ommited local (info)
]]

-- default strings
TITAN_ITEMRACK_BUTTON_LABEL = "ItemRack "
TITAN_ITEMRACK_BUTTON_NO_LABEL = " "
TITAN_ITEMRACK_BUTTON_SHOWSETNAME = "Show Set Name"

-- globals
TITAN_ITEMRACK_ID = "ItemRack"

local info = {}

function TitanPanelItemRackButton_OnLoad()
	this.registry = { 
		id = "ItemRack",
		menuText = "ItemRack", 
		buttonTextFunction = "TitanPanelItemRackButton_GetButtonText", 
		tooltipTitle = "ItemRack v"..tostring(ItemRack_Version),
		tooltipTextFunction = "TitanPanelItemRackButton_GetTooltipText",
		icon = "Interface\\AddOns\\ItemRack\\ItemRack-Icon",
		iconWidth = 16,
		savedVariables = {
			ShowLabelText = 1,  -- Default to 1
			ShowSetName = 1,
			ShowIcon = 1
		}
	}

	if tonumber(ItemRack_Version) and tonumber(ItemRack_Version)>1.82 then
		TITAN_ITEMRACK_BUTTON_HINT_TEXT	= "Hint: Left-click to choose a set"
	else
		TITAN_ITEMRACK_BUTTON_HINT_TEXT = "ItemRack v1.83+ required"
	end

end

function TitanPanelItemRackButton_GetButtonText(id)
	-- If id not nil, return corresponding plugin button
	-- Otherwise return this button and derive the real id
	local button, id = TitanUtils_GetButton(id, true)
	local itemrackRichText = ""
	local setName,setIcon

	if ItemRack_GetUserSets then
		_,setName,setIcon = ItemRack_GetUserSets()

		if (TitanGetVar(TITAN_ITEMRACK_ID, "ShowIcon")) then
			TitanUtils_GetPlugin(id).icon = setIcon
			TitanPanelItemRackButtonIcon:SetTexCoord(.075,.925,.075,.925)
		end
		
		-- create the string to return to the display
		if (TitanGetVar(TITAN_ITEMRACK_ID, "ShowSetName")) then
			itemrackRichText = TitanUtils_GetHighlightText(setName or "none").." "
		end
	end

	-- adding some space if the user elects to not show label text	
	if (TitanGetVar(TITAN_ITEMRACK_ID, "ShowLabelText")) then
		return TITAN_ITEMRACK_BUTTON_LABEL, itemrackRichText
	else
		itemrackRichText = TITAN_ITEMRACK_BUTTON_NO_LABEL..itemrackRichText	
		return TITAN_ITEMRACK_BUTTON_LABEL, itemrackRichText
	end
end

function TitanPanelItemRack_OnMouseUp(arg1)
	if arg1=="LeftButton" then
		TitanItemRack_MenuToggle()
		TitanPanelItemRackButtonIcon:SetTexCoord(.075,.925,.075,.925)
	end
end

function TitanPanelItemRack_OnMouseDown(arg1)
	if arg1=="LeftButton" then
		TitanPanelItemRackButtonIcon:SetTexCoord(0,1,0,1)
	end
end

function TitanPanelRightClickMenu_PrepareItemRackMenu()
	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_ITEMRACK_ID].menuText)

	info.text = TITAN_ITEMRACK_BUTTON_SHOWSETNAME
	info.func = TitanPanelItemRack_ToggleShowSetName
	info.checked = TitanGetVar(TITAN_ITEMRACK_ID, "ShowSetName")
	info.keepShownOnClick = 1
	UIDropDownMenu_AddButton(info)
	
	TitanPanelRightClickMenu_AddSpacer()

	info.text = "Options"
	info.func = ItemRack_Sets_Toggle
	info.checked = nil
	info.keepShownOnClick = nil
	UIDropDownMenu_AddButton(info)

	TitanPanelRightClickMenu_AddSpacer()

	TitanPanelRightClickMenu_AddToggleIcon(TITAN_ITEMRACK_ID)	
	TitanPanelRightClickMenu_AddToggleLabelText(TITAN_ITEMRACK_ID)	
	TitanPanelRightClickMenu_AddCommand(TITAN_PANEL_MENU_HIDE, TITAN_ITEMRACK_ID, TITAN_PANEL_MENU_FUNC_HIDE)
	ItemRack_MenuFrame:Hide()
end

function TitanPanelItemRackButton_GetTooltipText()
	return "Set: "..(ItemRack_CurrentSet() or "none").."\n"..TitanUtils_GetGreenText(TITAN_ITEMRACK_BUTTON_HINT_TEXT)
end

function TitanPanelItemRack_ToggleShowSetName()
	TitanToggleVar(TITAN_ITEMRACK_ID, "ShowSetName")
	TitanPanelButton_UpdateButton(TITAN_ITEMRACK_ID)
end

-- triggered by ItemRack on draw_inv
function ItemRack_UpdatePlugins()
	TitanPanelButton_UpdateButton(TITAN_ITEMRACK_ID)
end

function TitanItemRack_MenuToggle()

	if tonumber(ItemRack_Version) and tonumber(ItemRack_Version)>1.82 then
		if ItemRack_MenuFrame:IsVisible() then
			ItemRack_MenuFrame:Hide()
		else
			ItemRack_BuildMenu(20,"TITAN")
		end
	else
		DEFAULT_CHAT_FRAME:AddMessage("ItemRack version 1.83 or greater is required to open sets from Titan.")
	end
end